@@ -209,7 +209,7 @@ export class PrivateDiagramTraceService extends ComponentLifecycleEventEmitter {
         const rootMenu: DocDbPopupActionI = {
             name: null,
             tooltip: "Start a trace from this equipment",
-            icon: 'highlighter',
+            icon: 'highlight',
             callback: null,
             children: [],
             closeOnCallback: false
